"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* this file is for development purpose only */
const express_1 = __importDefault(require("express"));
const sequelize_1 = require("sequelize");
const cors_1 = __importDefault(require("cors"));
const index_1 = require("./index");
const app = (0, express_1.default)();
app.use((0, cors_1.default)());
app.use(express_1.default.json());
app.use(express_1.default.urlencoded({ extended: true }));
const sequelize = new sequelize_1.Sequelize("test_server", "iamadmin", "admin", {
    host: "localhost",
    dialect: "postgres",
});
sequelize
    .authenticate()
    .then(() => console.log("connected to db"))
    .catch((error) => {
    console.error("Unable to connect to the database:", error);
});
/* virtual field __title__ should be added for better readibility in admin pannel  */
const Director = sequelize.define("Director", {
    name: { type: sequelize_1.DataTypes.STRING, allowNull: true },
    birthDate: { type: sequelize_1.DataTypes.DATE },
    description: { type: sequelize_1.DataTypes.TEXT },
    __title__: {
        type: sequelize_1.DataTypes.VIRTUAL,
        get() {
            return `${this.getDataValue("name")}`;
        },
    },
});
const Movie = sequelize.define("Movie", {
    id: {
        type: sequelize_1.DataTypes.INTEGER,
        primaryKey: true,
        autoIncrement: true,
    },
    name: {
        allowNull: false,
        type: sequelize_1.DataTypes.STRING,
    },
    //after defining association the field must be specified in the model or else our library will have no way to know existance of that relation
    DirectorId: {
        type: sequelize_1.DataTypes.INTEGER,
        references: {
            model: "Directors",
            key: "id",
        },
    },
    __title__: {
        type: sequelize_1.DataTypes.VIRTUAL,
        get() {
            return `${this.getDataValue("name")}`;
        },
    },
});
const ActorProfle = sequelize.define("ActorProfile", {
    photo: sequelize_1.DataTypes.STRING,
    description: sequelize_1.DataTypes.TEXT,
    __title__: {
        type: sequelize_1.DataTypes.VIRTUAL,
        get() {
            return this.getDataValue("photo");
        },
    },
});
const Actor = sequelize.define("Actor", {
    name: { type: sequelize_1.DataTypes.STRING, allowNull: true },
    successor: {
        type: sequelize_1.DataTypes.STRING,
        defaultValue: "Don Didi",
    },
    ActorProfileId: {
        type: sequelize_1.DataTypes.INTEGER,
        references: { model: ActorProfle, key: "id" },
    },
    isAlive: {
        type: sequelize_1.DataTypes.BOOLEAN,
        defaultValue: true,
    },
    __title__: {
        type: sequelize_1.DataTypes.VIRTUAL,
        get() {
            return `${this.getDataValue("name")}`;
        },
    },
});
const ActorMovies = sequelize.define("ActorMovies", {
    MovieId: {
        type: sequelize_1.DataTypes.INTEGER,
        references: {
            model: "Movies",
            key: "id",
        },
    },
    ActorId: {
        type: sequelize_1.DataTypes.INTEGER,
        references: {
            model: "Actors",
            key: "id",
        },
    },
    __title__: {
        type: sequelize_1.DataTypes.VIRTUAL,
        get() {
            return `${this.getDataValue("MovieId")},${this.getDataValue("ActorId")}`;
        },
    },
});
//after defining association the field must be specified in the model or else our library will have no way to know existance of that relation
Director.hasMany(Movie);
/* here since movie belongs to Director a DirectorId field will be added to model automatically during runtime but to use the library, the field must be specified in the model */
Movie.belongsTo(Director);
ActorProfle.hasOne(Actor);
Actor.belongsTo(ActorProfle); /* in model ActorProfileId */
Movie.belongsToMany(Actor, { through: ActorMovies });
Actor.belongsToMany(Movie, { through: ActorMovies });
// async function notW() {
//   await sequelize.sync({ force: true });
//   const profile = await ActorProfle.create({
//     photo: "some link",
//     description: "this is description",
//   });
//   const newactor = await Actor.create({
//     name: "test name",
//     successor: "noone",
//   });
//   const newdir = await Director.create({
//     name: "test name of director",
//     birthDate: "Wed Sep 28 2022 19:09:21 GMT+0545 (Nepal Time) ",
//     description: "asdf",
//   });
//   const movie = await Movie.create({
//     name: "my movie",
//     director: newdir.name,
//   });
// }
// notW();
//arguments: name of orm,instance of db,express app,options
const adminPannel = new index_1.AdminPannel("sequelize", sequelize, app, {
    titleFields: {
        Actor: ["name", "successor"],
        Movie: ["__title__", "DirectorId"],
        ActorProfile: ["photo", "__title__"],
        Director: ["__title__", "id"],
    },
    imageFields: { ActorProfile: ["photo"] },
    noOfItemsPerPage: 6,
});
adminPannel.initialize("admin");
app.listen(8000, () => console.log("client listening at port 8000"));
