"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SequelizeHelper = void 0;
const sequelize_1 = require("sequelize");
class SequelizeHelper {
    constructor() { }
    extractModelInfo() {
        return Object.entries(dbInstance.models).map(([tableName, model]) => {
            return {
                tableName: tableName,
                fields: this.getModelFieldInfo(model),
                primaryKeyFields: model.primaryKeyAttributes,
            };
        });
    }
    getAll(modelName) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = this.getModel(modelName);
            if (!model)
                throw new Error("invalid model name");
            return model.findAll();
        });
    }
    createOne(modelName, body) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = this.getModel(modelName);
            if (!model)
                throw new Error("invalid model name");
            return model.create(Object.assign({}, body));
        });
    }
    delete(modelName, whereFields) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!Array.isArray(whereFields))
                whereFields = [whereFields];
            const model = this.getModel(modelName);
            if (!model)
                throw new Error("invalid model name");
            return Promise.all(whereFields.map((whereField) => model.destroy({ where: Object.assign({}, whereField) })));
        });
    }
    updateOne(modelName, pk, newValues) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = this.getModel(modelName);
            if (!model)
                throw new Error("invalid model name");
            const item = yield model.findOne({ where: Object.assign({}, pk) });
            if (!item)
                throw new Error("no item matched given pk!!");
            Object.entries(newValues).forEach(([key, value]) => item.setDataValue(key, value));
            return item.save();
        });
    }
    filter(modelName, key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = this.getModel(modelName);
            if (!model)
                throw new Error("invalid model name");
            return model.findAll({ where: { [key]: { [sequelize_1.Op.iLike]: `%${value}%` } } });
        });
    }
    getModelFieldInfo(model) {
        const modelAttributes = model.getAttributes();
        return Object.entries(modelAttributes)
            .map(([fieldName, fieldProperties]) => {
            if (fieldProperties.autoIncrement || fieldProperties._autoGenerated)
                return;
            return {
                type: this.getType(fieldProperties.type),
                fieldName: fieldName,
                allowNull: fieldProperties.allowNull,
                defaultValue: fieldProperties.defaultValue,
                relationWith: fieldProperties.references,
            };
        })
            .filter((i) => i !== undefined);
    }
    getType(typeInstance) {
        if (typeInstance instanceof sequelize_1.DataTypes.BOOLEAN)
            return "boolean";
        if (typeInstance instanceof sequelize_1.DataTypes.TEXT)
            return "text";
        if (typeInstance instanceof sequelize_1.DataTypes.INTEGER)
            return "number";
        if (typeInstance instanceof sequelize_1.DataTypes.DATE)
            return "date";
        if (typeInstance instanceof sequelize_1.DataTypes.STRING)
            return "string";
    }
    getModel(modelName) {
        /* model name can be given as "s" in end or without an "s" in end */
        let model = dbInstance.models[modelName];
        if (!model) {
            model = dbInstance.models[modelName + "s"];
        }
        if (!model && modelName.endsWith("s")) {
            model = dbInstance.models[modelName.slice(0, -1)];
        }
        return model;
    }
}
exports.SequelizeHelper = SequelizeHelper;
