"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const response_1 = require("../utils/response");
const SequelizeHelper_1 = require("../orm/SequelizeHelper");
const paginator_1 = require("../utils/paginator");
const apiRouter = (0, express_1.Router)();
/* should contain helpers for all supported orms */
const ormHelpers = {
    sequelize: new SequelizeHelper_1.SequelizeHelper(),
};
apiRouter.get("/admin-pannel-options/", (req, res) => {
    return res.json(AdminPannelOptions || {});
});
/* will return description of all model tables to frontend */
apiRouter.get("/model-infos/", (req, res) => {
    const ormHelper = ormHelpers[appOrm];
    const modelInfos = ormHelper.extractModelInfo();
    return res.json(modelInfos);
});
/* will return values that can be used as values for relation in model */
apiRouter.post("/model-values/:modelName/", (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const ormHelper = ormHelpers[appOrm];
    try {
        const allOptions = yield ormHelper.getAll(req.params.modelName);
        if (req.body.paginate) {
            return res.json((0, paginator_1.paginator)(allOptions, req.query.page));
        }
        return res.json(allOptions);
    }
    catch (error) {
        return (0, response_1.sendError)(res, error);
    }
}));
/* will delete all tabel values matching given values and returns new value */
apiRouter.post("/delete/:modelName", (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const ormHelper = ormHelpers[appOrm];
    const modelName = req.params.modelName;
    try {
        const itemsCount = yield ormHelper.delete(modelName, Object.assign({}, req.body.where));
        const newValues = yield ormHelper.getAll(modelName);
        return res.json({
            message: `Deleted ${itemsCount} item${itemsCount > 1 ? "s" : ""} Successfully!`,
            newValues,
        });
    }
    catch (error) {
        return (0, response_1.sendError)(res, error);
    }
}));
apiRouter.post("/create/:modelName/", (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { modelName } = req.params;
    const ormHelper = ormHelpers[appOrm];
    try {
        const response = yield ormHelper.createOne(modelName, Object.assign({}, req.body));
        return res.json({
            message: `${modelName} created successfully!`,
            response,
        });
    }
    catch (error) {
        return (0, response_1.sendError)(res, error);
    }
}));
apiRouter.post("/update/:modelName/", (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { modelName } = req.params;
    const { pk, newValues } = req.body;
    const ormHelper = ormHelpers[appOrm];
    try {
        const response = yield ormHelper.updateOne(modelName, pk, newValues);
        return res.json({
            message: `${modelName} updated successfully!`,
            response,
        });
    }
    catch (error) {
        return (0, response_1.sendError)(res, error);
    }
}));
apiRouter.post("/filter/:modelName/", (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { modelName } = req.params;
    const { key, value } = req.body;
    const ormHelper = ormHelpers[appOrm];
    try {
        const allOptions = yield ormHelper.filter(modelName, key, value);
        if (req.body.paginate) {
            return res.json((0, paginator_1.paginator)(allOptions, req.query.page));
        }
        return res.json(allOptions);
    }
    catch (error) {
        return (0, response_1.sendError)(res, error);
    }
}));
exports.default = apiRouter;
